==> seedsui-react-5.7.93.tgz: package/lib/Image/Status.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import React, { useState } from 'react';

// 状态:choose|uploading|fail|success
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Status = function Status(_ref) {
  var onReUpload = _ref.onReUpload,
    statusRender = _ref.statusRender;
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    statusDOM = _useState2[0],
    setStatusDOM = _useState2[1];

  // render icon
  function getStatusIcon() {
    // Custom Status
    var customStatusNode = null;
    if (typeof statusRender === 'function') {
      var itemDOM = statusDOM.parentNode;
      var itemType = 'image';
      if (itemDOM.classList.contains('image-upload')) {
        itemType = 'upload';
      }
      customStatusNode = statusRender({
        rootDOM: itemDOM.parentNode,
        itemDOM: itemDOM,
        itemType: itemType
      });
    }
    if ( /*#__PURE__*/React.isValidElement(customStatusNode)) {
      return customStatusNode;
    }

    // Default Status
    return /*#__PURE__*/_jsxs("div", {
      className: "image-status-icon",
      children: [/*#__PURE__*/_jsx("div", {
        className: "image-status-icon-fail"
      }), /*#__PURE__*/_jsx("svg", {
        viewBox: "25 25 50 50",
        className: "image-status-icon-loading",
        children: /*#__PURE__*/_jsx("circle", {
          cx: "50",
          cy: "50",
          r: "20"
        })
      })]
    });
  }
  return /*#__PURE__*/_jsx("div", {
    ref: setStatusDOM,
    className: "image-status",
    onClick: function onClick(e) {
      e.stopPropagation();
      // 上传失败允许重新上传
      if (e.currentTarget.parentNode.classList.contains('fail')) {
        onReUpload && onReUpload(e);
      }
    },
    children: statusDOM && getStatusIcon()
  });
};
export default Status;

==> seedsui-react-5.8.44.tgz: package/lib/Image/Status.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import React, { useState } from 'react';

// 状态:choose|uploading|fail|success
var Status = function Status(_ref) {
  var onReUpload = _ref.onReUpload,
    statusRender = _ref.statusRender;
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    statusDOM = _useState2[0],
    setStatusDOM = _useState2[1];

  // render icon
  function getStatusIcon() {
    // Custom Status
    var customStatusNode = null;
    if (typeof statusRender === 'function') {
      var itemDOM = statusDOM.parentNode;
      var itemType = 'image';
      if (itemDOM.classList.contains('image-upload')) {
        itemType = 'upload';
      }
      customStatusNode = statusRender({
        rootDOM: itemDOM.parentNode,
        itemDOM: itemDOM,
        itemType: itemType
      });
    }
    if ( /*#__PURE__*/React.isValidElement(customStatusNode)) {
      return customStatusNode;
    }

    // Default Status
    return /*#__PURE__*/React.createElement("div", {
      className: "image-status-icon"
    }, /*#__PURE__*/React.createElement("div", {
      className: "image-status-icon-fail"
    }), /*#__PURE__*/React.createElement("svg", {
      viewBox: "25 25 50 50",
      className: "image-status-icon-loading"
    }, /*#__PURE__*/React.createElement("circle", {
      cx: "50",
      cy: "50",
      r: "20"
    })));
  }
  return /*#__PURE__*/React.createElement("div", {
    ref: setStatusDOM,
    className: "image-status",
    onClick: function onClick(e) {
      e.stopPropagation();
      // 上传失败允许重新上传
      if (e.currentTarget.parentNode.classList.contains('fail')) {
        onReUpload && onReUpload(e);
      }
    }
  }, statusDOM && getStatusIcon());
};
export default Status;
